==> crop-0.5.3.tar.gz: CHANGELOG.md <==
## [0.5.3] - 2022/10/21

- Upgrade to flutter_lints version 2.

## [0.5.2] - 2022/01/03

- More Documentation.

## [0.5.1+2] - 2021/06/24

- Documentation.

## [0.5.1+1] - 2021/05/30

- Documentation.


## [0.5.1] - 2021/05/07

- Support two-finger rotation gesture.

## [0.5.0] - 2021/03/03

- Flutter 2.0 and Dart 2.12.0 support.

## [0.4.3] - 2021/02/09

- Migrate to null-safety

## [0.4.3-nullsafety.0] - 2020/11/25

- Null-safety

## [0.4.2] - 2020/11/24

- Web support (via CanvasKit/Skia)

## [0.4.1] - 2020/08/14

- Crop widget gets `onChanged` propery. Thanks to @sanjul.

## [0.4.0] - 2020/06/26

- Adds support for Oval crop area. Special thanks to @songfei for his contribution and inspiration.
- Example project updated with a crop shape selector.

## [0.3.2] - 2020/06/17

- Fixes an issue causing the image go off-canvas when playing with aspect-ratio and panning.

## [0.3.1] - 2020/04/09

- Fixes a bug when the rotation is more than 90 degrees (or less than -90).
- Updated the example project to let the rotation slider move between -180 and +180 degrees.

## [0.3.0] - 2020/04/05

- Introduces `helper` parameter.
- Ditches `borderWidth` and `borderColor` parameters in favor of the new `helper` parameter (Breaking Change). You should see the example project to figure out how to bring borders back to your UI.

## [0.2.2] - 2020/03/30

- Adds Support for background widget.
- Layout and Paint more efficiently.

## [0.2.1] - 2020/03/29

- Fixes a bug when child's aspect-ratio does not match the canvas's aspect ratio.

## [0.2.0]

- Introduced CropController (Breaking Change).

## [0.1.3]

- Optionally takes pixelRatio for better output quality.

## [0.1.1]

- Update documentation and improvements to the package health.

## [0.1.0]

- Initial release of the package.

## [0.0.1]

- Initialize package placeholder.

==> crop-0.5.4.tar.gz: CHANGELOG.md <==
## 0.5.4

- More dartdoc comments.

## 0.5.3

- Upgrade to flutter_lints version 2.

## 0.5.1

- Support two-finger rotation gesture.
- Documentations.

## 0.5.0

- Flutter 2.0 and Dart 2.12.0 support.

## 0.4.3

- Migration to null-safety

## 0.4.2

- Web support (via CanvasKit/Skia)

## 0.4.1

- Crop widget gets `onChanged` propery. Thanks to @sanjul.

## 0.4.0

- Adds support for Oval crop area. Special thanks to @songfei for his contribution and inspiration.
- Example project updated with a crop shape selector.

## 0.3.2

- Fixes an issue causing the image go off-canvas when playing with aspect-ratio and panning.

## 0.3.1

- Fixes a bug when the rotation is more than 90 degrees (or less than -90).
- Updated the example project to let the rotation slider move between -180 and +180 degrees.

## 0.3.0

- Introduces `helper` parameter.
- Ditches `borderWidth` and `borderColor` parameters in favor of the new `helper` parameter (Breaking Change). You should see the example project to figure out how to bring borders back to your UI.

## 0.2.2

- Adds Support for background widget.
- Layout and Paint more efficiently.

## 0.2.1

- Fixes a bug when child's aspect-ratio does not match the canvas's aspect ratio.

## 0.2.0

- Introduced CropController (Breaking Change).

## 0.1.3

- Optionally takes pixelRatio for better output quality.

## 0.1.1

- Update documentation and improvements to the package health.

## 0.1.0

- Initial release of the package.

## 0.0.1

- Initialize package placeholder.
